---------------------------------------------------
-- Config
---------------------------------------------------
local LSM = LibStub("LibSharedMedia-3.0")
local AceGUI = LibStub("AceGUI-3.0")
local OptionsFrame
local db
local SelectedOption, OptionsStatus = nil, {selected = "ShowAndHide"}
local UIF
local mMinimapIcon = [[Interface\Icons\INV_Offhand_Sunwell_D_01]]


function mMinimap:ChangeCallback(widget, event, ...)
	if widget and not widget.GetUserData then
		widget = self
		self = mMinimap
		if widget:GetUserData("key") == "MinimapPositionX" or widget:GetUserData("key") == "MinimapPositionY" then
			db.MinimapPositionSet = true
		end
	end		
	self:ShowHideFrames()
	self:Update()
end

function mMinimap:ToggleConfigIfVisible()
	if OptionsFrame and OptionsFrame.frame:IsShown() then
		self:ToggleConfig()
		self:ToggleConfig()
	end
end

function mMinimap:ToggleConfig()
	UIF = LibStub("LibGUIFactory-1.0"):GetFactory("mMinimap")
	db = self.db.profile
	if not OptionsFrame then	
		OptionsFrame = UIF:Frame("mMinimap")
		OptionsFrame:SetLayout("Fill")
		OptionsFrame:SetWidth(813)
		OptionsFrame:SetHeight(630)
		OptionsFrame:Hide()			
		OptionsFrame:SetCallback("OnClose", function(widget)				
			OptionsFrame:ReleaseChildren()		
			OptionsFrame.frame:Hide()
		end)			
	end
	
	if OptionsFrame.frame:IsShown() then
		OptionsFrame:Hide()
	else			
		m = UIF:TreeGroup()
		m:SetLayout("Fill")	
		m:SetCallback("OnGroupSelected", function(self, event, group) SelectedOption = group end)									
		OptionsFrame:AddChild(m)
		
		-- Toggles
		m:AddGroup({{text = "Show & Hide", value = "ShowAndHide"}},
			function()				
				local text = UIF:NormalText(
[[- Right click will show the tracking menu.
- Middle click shows the calendar.
- Hover over to show the clock (and tracking icon if it is hidden).]]) 
				text:SetImage(mMinimapIcon)
				local group = UIF:InlineGroup("Information")
				group:AddChild(text)					
				
				local m = UIF:InlineGroup()
				m:SetFullWidth(true)
				local check = UIF:CheckBox("Lock Minimap", db, "MinimapLocked", mMinimap.ChangeCallback, "While locked, the Minimap cannot be moved with the mouse.")
				check:SetRelativeWidth(0.6)
				m:AddChild(check)
				check = UIF:CheckBox("Move \"Looking For Dungeon\" tooltip", db, "MoveLFDFrame", mMinimap.ChangeCallback, "This will move the tooltip to the middle of the screen")
				check:SetRelativeWidth(0.6)
				m:AddChild(check)
				check = UIF:CheckBox("Hide tracking icon", db, "HideTracking", mMinimap.ChangeCallback, "If hidden right click on the Minimap will show the tracking menu.")
				check:SetRelativeWidth(0.6)
				m:AddChild(check)
				check = UIF:CheckBox("Hide Clock", db, "HideClock", mMinimap.ChangeCallback, "Hide the clock. It will be visible while hovering over the minimap instead.")
				check:SetRelativeWidth(0.6)
				m:AddChild(check)		
				check = UIF:CheckBox("Replace new mail icon", db, "ReplaceMailIcon", mMinimap.ChangeCallback, "Will replace the new mail icon with a text saying the same thing.")
				check:SetRelativeWidth(0.6)
				m:AddChild(check)
				check = UIF:CheckBox("Show Coordinates", db, "ShowCoords", mMinimap.ChangeCallback, "Shows your current coordinates on the botom of the minimap. If hidden it will show on mouseover.")
				check:SetRelativeWidth(0.6)
				m:AddChild(check)						
				check = UIF:CheckBox("Show Frames", db, "ShowFrameAnchors", mMinimap.ChangeCallback, "Show anchors for frames like the Durability frame and capture bar so they can be moved.")
				check:SetRelativeWidth(0.6)
				m:AddChild(check)			
				
				return group, m
			end)
			
		-- Posistion and scale
		m:AddGroup({{text = "Position & Scale", value = "Pos"}},
			function()
				local group = UIF:InlineGroup("Position and Scale")
				slider = UIF:Slider("X", db, "MinimapPositionX", 
					-floor(GetScreenWidth() * UIParent:GetEffectiveScale()), 
					floor(GetScreenWidth() * UIParent:GetEffectiveScale()), 0.1, mMinimap.ChangeCallback)
				PostionXWidget = slider
				group:AddChild(slider)
				slider = UIF:Slider("Y", db, "MinimapPositionY", 
					-floor(GetScreenHeight() * UIParent:GetEffectiveScale()), 
					floor(GetScreenHeight() * UIParent:GetEffectiveScale()), 0.1, mMinimap.ChangeCallback)
				PostionYWidget = slider
				group:AddChild(slider)
				group:AddChild(UIF:Slider("Scale", db, "MinimapScale", 0.01, 10, 0.01, mMinimap.ChangeCallback))
				
				local group2 = UIF:InlineGroup("Zone Text Positon")
				group2:AddChild(UIF:Slider("Offset X", db, "ZoneTextX", -50, 50, 0.1, mMinimap.ChangeCallback))
				group2:AddChild(UIF:Slider("Offset Y", db, "ZoneTextY", -200, 200, 0.1, mMinimap.ChangeCallback))
				
				local coords = UIF:Slider("Coordinates Precition", db, "CoordsPrecition", 0, 3, 1, mMinimap.ChangeCallback)
				
				return group, group2, coords
			end)
		
		-- Font and Border
		m:AddGroup({{text = "Font and Background", value = "FontBorder"}},
			function()
				local group = UIF:InlineGroup("Font Settings")
				group:AddChild(UIF:LSMDropdown("font", "Font", db, "ZoneFont", mMinimap.ChangeCallback))
				local select = UIF:Dropdown("Outline", db, "ZoneFontFlags", mMinimap.ChangeCallback, {OUTLINE = "Outline", THICKOUTLINE = "Thick Outline", NONE = "None"})
				select:SetWidth(140)
				group:AddChild(select)
				
				group:AddChild(UIF:NewLine())					
				group:AddChild(UIF:Slider("Size", db, "ZoneFontSize", 1, 50, 1, mMinimap.ChangeCallback))	
				group:AddChild(UIF:Slider("Shadow offset", db, "ZoneFontShadow", 0, 5, 0.1, mMinimap.ChangeCallback))	
				
				group:AddChild(UIF:NewLine())	
				group:AddChild(UIF:ColorSelect("Color", db, "ZoneFontColor", mMinimap.ChangeCallback))	

				local group2 = UIF:InlineGroup("Background")					
				local check = UIF:CheckBox("Show Background", db, "ShowBackdrop", mMinimap.ChangeCallback)
				group2:AddChild(check)
				
				group2:AddChild(UIF:LSMDropdown("background", "Background", db, "BGTexture", mMinimap.ChangeCallback))
				group2:AddChild(UIF:LSMDropdown("border", "Border", db, "BGBorderTexture", mMinimap.ChangeCallback))		
				group2:AddChild(UIF:NewLine())
				
				group2:AddChild(UIF:Slider("Insets", db, "BGInset", 0, 50, 0.1, mMinimap.ChangeCallback))			
				group2:AddChild(UIF:Slider("Border Size", db, "BGBorderSize", 0.1, 100, 0.1, mMinimap.ChangeCallback))
				group2:AddChild(UIF:Slider("Background Size", db, "BackdropExtent", 0, 50, 0.1, mMinimap.ChangeCallback))	
				group2:AddChild(UIF:NewLine())
				
				local color = UIF:ColorSelect("BG Color", db, "BGColor", mMinimap.ChangeCallback)		
				color:SetHasAlpha(true)
				group2:AddChild(color)
				color = UIF:ColorSelect("Border Color", db, "BGBorderColor", mMinimap.ChangeCallback)
				color:SetHasAlpha(true)
				group2:AddChild(color)																
									
				return group, group2
			end)
		
		-- Frameanchors
		m:AddGroup({{text = "Moveable Frames", value = "MoveFrames"}},
			function()
				local CheckBox = UIF:CheckBox("Show movable frames", db, "ShowFrameAnchors", mMinimap.ChangeCallback, "Show frames to use for moving frames like the quest tracker, ticket status and so on.")
				local group = UIF:InlineGroup("Positions")
				
				for frameName, frame in pairs(mMinimap.MultiFrames) do
					if mMinimap.FrameRealNames[frameName] and db.FramePositions[frameName] and db.FramePositions[frameName][1] then
						local slider = UIF:Slider(mMinimap.FrameRealNames[frameName].." X", db.FramePositions[frameName], 1, -1000, 1000, 1, mMinimap.SetAllFramePositions)
						group:AddChild(slider)
						local slider = UIF:Slider(mMinimap.FrameRealNames[frameName].." Y", db.FramePositions[frameName], 2, -1000, 1000, 1, mMinimap.SetAllFramePositions)					
						group:AddChild(slider)
						local nl = UIF:NewLine(10)
						group:AddChild(nl)
					end
				end
				
				local group2 = UIF:InlineGroup("Quest Tracker Size")
				local slider = UIF:Slider("Width", db, "WatchFrameWidth",  50, 800, 1, mMinimap.SetAllFramePositions)
				group2:AddChild(slider)
				local slider = UIF:Slider("Height", db, "WatchFrameHeight",  50, 1200, 1, mMinimap.SetAllFramePositions)					
				group2:AddChild(slider)
				
				return CheckBox, group, group2
			end)
		
		-- Profile
		m:AddGroup({{text = "Profile", value = "Profile"}},
			function()
				return UIF:AceProfileOption(mMinimap.db)
			end)						
						
		m:SetSelected(SelectedOption or "ShowAndHide")
		m:SetStatusTable(OptionsStatus)	
		OptionsFrame:Show()
	end
end
